@@ -4,31 +4,31 @@
 
 #include "frc2/command/CommandGroupBase.h"
 
-#include <frc/WPIErrors.h>
-
 using namespace frc2;
 
-bool CommandGroupBase::RequireUngrouped(Command& command) {
+bool CommandGroupBase::RequireUngrouped(const Command& command) {
   if (command.IsGrouped()) {
-    // wpi_setGlobalWPIErrorWithContext(
-    //     CommandIllegalUse,
-    throw std::runtime_error("Commands cannot be added to more than one CommandGroup");
-    // return false;
-  } else {
-    return true;
+    throw FRC_MakeError(
+        frc::err::CommandIllegalUse, "{}",
+        "Commands cannot be added to more than one CommandGroup");
   }
+  return true;
+}
+
+bool CommandGroupBase::RequireUngrouped(const Command* command) {
+  return RequireUngrouped(*command);
 }
 
 bool CommandGroupBase::RequireUngrouped(
-    wpi::ArrayRef<std::shared_ptr<Command>> commands) {
+    wpi::span<std::shared_ptr<Command>> commands) {
   bool allUngrouped = true;
   for (auto&& command : commands) {
     allUngrouped &= !command.get()->IsGrouped();
   }
   if (!allUngrouped) {
-    // wpi_setGlobalWPIErrorWithContext(
-    //     CommandIllegalUse,
-    throw std::runtime_error("Commands cannot be added to more than one CommandGroup");
+    throw FRC_MakeError(
+        frc::err::CommandIllegalUse, "{}",
+        "Commands cannot be added to more than one CommandGroup");
   }
   return allUngrouped;
 }
@@ -40,9 +40,9 @@ bool CommandGroupBase::RequireUngrouped(
     allUngrouped &= !command->IsGrouped();
   }
   if (!allUngrouped) {
-    // wpi_setGlobalWPIErrorWithContext(
-    //     CommandIllegalUse,
-    throw std::runtime_error("Commands cannot be added to more than one CommandGroup");
+    throw FRC_MakeError(
+        frc::err::CommandIllegalUse, "{}",
+        "Commands cannot be added to more than one CommandGroup");
   }
   return allUngrouped;
 }
