@@ -13,7 +13,7 @@ InstantCommand::InstantCommand(std::function<void()> toRun,
 }
 
 InstantCommand::InstantCommand(std::function<void()> toRun,
-                               wpi::ArrayRef<std::shared_ptr<Subsystem>> requirements)
+                               wpi::span<std::shared_ptr<Subsystem>> requirements)
     : m_toRun{std::move(toRun)} {
   AddRequirements(requirements);
 }
