@@ -6,13 +6,17 @@
 
 using namespace frc2;
 
-ScheduleCommand::ScheduleCommand(wpi::ArrayRef<std::shared_ptr<Command>> toSchedule) {
+ScheduleCommand::ScheduleCommand(wpi::span<std::shared_ptr<Command>> toSchedule) {
   SetInsert(m_toSchedule, toSchedule);
 }
 
+ScheduleCommand::ScheduleCommand(std::shared_ptr<Command> toSchedule) {
+  SetInsert(m_toSchedule, {&toSchedule, 1});
+}
+
 void ScheduleCommand::Initialize() {
   for (auto command : m_toSchedule) {
-    command->Schedule();
+    Command_Schedule(command);
   }
 }
 
